@@ -15,8 +15,8 @@ use std::matches;
 use uuid::Uuid;
 
 pub use chrono::{DateTime, Utc};
-pub use http;
 pub use dropshot;
+pub use http;
 
 pub mod address;
 pub mod error;
@@ -25,8 +25,8 @@ pub mod invoice;
 pub mod item;
 pub mod money;
 pub mod price;
-pub mod shipping;
 pub mod server;
+pub mod shipping;
 
 #[derive(Serialize, Deserialize, JsonSchema)]
 pub enum State {
@@ -52,10 +52,7 @@ pub struct Checkout {
 
 impl Checkout {
     // private methods
-    async fn enter_shopping_state<C: Context + Send>(
-        &mut self,
-        ctx: &mut C,
-    ) -> Result<(), Error> {
+    async fn enter_shopping_state<C: Context + Send>(&mut self, ctx: &mut C) -> Result<(), Error> {
         match self.state {
             State::Shopping => Ok(()),
             State::ItemsConfirmed(_) => {
@@ -70,17 +67,11 @@ impl Checkout {
         }
     }
 
-    async fn update_invoice<C: Context + Send>(
-        &mut self,
-        ctx: &mut C,
-    ) -> Result<(), Error> {
+    async fn update_invoice<C: Context + Send>(&mut self, ctx: &mut C) -> Result<(), Error> {
         Ok(self.invoice = Some(ctx.generate_invoice(self).await?))
     }
 
-    pub async fn create<C: Context + Send>(
-        ctx: &mut C,
-        currency: Currency,
-    ) -> Result<Self, Error> {
+    pub async fn create<C: Context + Send>(ctx: &mut C, currency: Currency) -> Result<Self, Error> {
         let checkout = Checkout {
             id: Uuid::new_v4(),
             state: State::Shopping,
@@ -162,10 +153,7 @@ impl Checkout {
         ctx.on_remove_item(self, &sku, quantity).await
     }
 
-    pub async fn confirm_items<C: Context + Send>(
-        &mut self,
-        ctx: &mut C,
-    ) -> Result<(), Error> {
+    pub async fn confirm_items<C: Context + Send>(&mut self, ctx: &mut C) -> Result<(), Error> {
         match self.state {
             State::ItemsConfirmed(_) => Ok(()),
             State::Shopping => {
@@ -315,8 +303,8 @@ pub trait Context:
 }
 
 #[async_trait]
-pub trait ContextProvider<T: Context> {
-    async fn new_context(&self) -> Result<T, Error>;
+pub trait ContextProvider<'a, T: Context> {
+    async fn new_context(&'a self) -> Result<T, Error>;
 }
 
 fn new_invalid_state_error(msg: &str) -> Error {
